@@ -72,7 +72,7 @@ class Pg:
         "データをソートして取得"
 
         column = f"{list(opt.keys())[0]} = $1"
-        limit = f"{list(opt.keys()[1])} $2"
+        limit = f"{list(opt.keys())[1]} $2"
 
         contents = await self.pool.fetch(f'SELECT * FROM {self.table} WHERE {column} ODER BY {target} DESC {limit}', *opt.values())
         return contents
